#ifndef _CLIMATE_H
#define _CLIMATE_H

typedef unsigned int uint;
typedef unsigned char uchar;

//iButton commands
#define SKIPR   0xCC
#define TxTIME  0x66
#define RxTIME  0x99
#define CONTROL 0x0C



//D1 and D2 from Sensirion data sheet
#define D1 40
#define D2 100

//T1 and T2 from data sheet use floating point maths. values T1= -0.01 T2=0.00008
//These roughly equate to the following using integer maths. Adjustments have been made to allow for fraction
//if using real numbers.
#define T1 8
#define T2 15600

#define SHT_bDATA bRC4
//#define LCD_BCKL bRA5
//#define PWR_OK bRA3
#define PB bRA2
#define Trip1 bRC5
#define Trip2 bRC1
#define TripH bRC2
#define MAX_MENU 5
#define WDT bRA3

//display column constants for LCD and VFD display
#ifndef VFD
	#define COLUMN3 0x84
	#define COLUMN10 0x8A
#else	
	#define COLUMN3 0x03
	#define COLUMN10 0x0A
#endif

struct trips
{
	uchar humidity;
	uchar undertemp;
	uchar overtemp;
};

trips trip; 

//Function prototypes
void setup();
void SHT_reset();
void SHT_start();
void SHT_write(unsigned char data);
void SHT_read();
void SHT_measureTemp(int *temp);
void SHT_hum_measure(int *p_humidity);
void fault(unsigned char eMode);
void tasktime();
void getenc();
void keypress();
void domenu();
void trip_check(trips *pTrip);
void display1(uchar value, uchar dig, uchar lz);

#ifndef VFD
const char splash[]={0x83,'C','L','I','-','M','A','T','E',0x20,'1',0};
const char error0[]={0x80,'E','r','r','o','r',0};
const char error1[]={0x86,'S','H','T',0};
#else
const char splash[]={0x05,'C','L','I','-','M','A','T','E',0x20,'1',0};
const char error0[]={0x01,'E','r','r','o','r',0};
const char error1[]={0x07,'S','H','T',0};
#endif

uchar *tripscrn[]={"0","S","uH","T1","T2"};

//Bit Flags for program 2bytes
struct 
{
  bit SHT_ack;	// send an acknowledge=1 cleared if noack
  bit keydown;	//Key action low to high set if down
  bit keydone;	//Key routine set if finished 
  bit Scale;  	//Centigrade Fahrenheight indicator - set if Fahrenheight
  bit T_sign;	//Temperature sign +?   cleared  ;  set if    - ?
  bit done;		//Transmission start or do conversion flag
  bit WDT_err;	//Ibutton 1904 connection error set if error
  bit SHT_err;	//Connection error  set if error, cleared otherwise
  bit spress;	//Short press set if valid
  bit lpress;	//Button held 500mS  set if valid
  bit oldpress;	//Last action state of button, set if high cleared if low
  bit Nobutt;	//Ibutton not present =1 Cleared if present
} sysflag; 

//Enumeration allows program to bit test  flag bits
enum eventflags {Nobutt=0x0B,oldpress=0x0A,lpress=0x09,spress=0x08,SHT_err=0x07,WDT_err=0x06,done=0x05,T_sign=0x04,Scale=0x03,keydone=0x02,keydown=0x01,SHT_ack=0x00};
				 
enum SHT_commands{RESET=0x1E,STATUS_R=0x07,STATUS_W=0x06,HUMID=0x05,TEMP=0x03};

//Program variables
uchar sht[3];			//sensor input array
uchar template[16];		//holding array for display data
uchar indata;			//buffer for incoming data
uchar count;			//holds splash delay ~3Secs count
uchar *pSht;			//pointer to sensor input array
uchar delay1=275;		//3.5Second delay for humidity routine
uchar delay2=0;			//3.5Second delay for Temperature. Init to zero as we take temp first.
uchar old_enc_state;	//Last state of encoder 
uchar menu;				//menu choice short button press
uchar lmenu;			//menu choice long button press
int t_c;				//Holds temperature reading
ulong rh_adj;			//Holds adjusted humidity reading, relative to 25 deg C
uchar buttonhold;		//Holds timing count for long button press
uchar enc_state;		//Returns either 0,1 or 255
uchar max_trip;			//Holds max trip temp in either degress F or C
uchar scale;			//returns either 'F' or 'C'
uchar conv_delay;		//Counter for 245mS conversion delay
uchar duty1;			//Duty cycle for CCP1
uchar duty2;			//Duty cycle for CCP2

